==> qtjambi-sensors-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiSensors/QCompassReading_shell.h <==
#ifndef QCOMPASSREADING_SHELL_H
#define QCOMPASSREADING_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSensors/qcompass.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSensors/qsensor.h>
#include <QtJambi/RegistryAPI>


class QCompassReading_shell : public QCompassReading, public QtJambiShellInterface
{
public:
    QCompassReading_shell(QObject* parent0 = nullptr);
    ~QCompassReading_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void copyValuesFrom(QSensorReading* other0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCompassReading_access : public QCompassReading
{
    void __qt_copyValuesFrom_QSensorReading_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
};

#endif // QCOMPASSREADING_SHELL_H

==> qtjambi-sensors-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiSensors/QCompassReading_shell.h <==
#ifndef QCOMPASSREADING_SHELL_H
#define QCOMPASSREADING_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSensors/qcompass.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSensors/qsensor.h>
#include <QtJambi/RegistryAPI>


class QCompassReading_shell : public QCompassReading, public QtJambiShellInterface
{
public:
    QCompassReading_shell(QObject* parent0 = nullptr);
    ~QCompassReading_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void copyValuesFrom(QSensorReading* other0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCompassReading_access : public QCompassReading
{
    void __qt_copyValuesFrom_QSensorReading_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
};

#endif // QCOMPASSREADING_SHELL_H
